/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSlice.h"
#include "HvControlCast.h"
#include "HvControlBinop.h"
#include "HvControlSystem.h"
#include "HvSignalLine.h"
#include "HvControlUnop.h"
#include "HvSignalBiquad.h"
#include "HvControlVar.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvControlIf.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_Nj7A0jXI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1ApRwfO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Eb40xFpb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5mkpxFet_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_99gjPaqI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_LpMxryyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n06GRgYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ACKcPhZE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JssBPvCQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_V83rdlK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_K4zMT0tA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LLGGFEcU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7sg2keBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AH8GkEYl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dCUXS88c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7zUks9y1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wzbarDCW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qityjlOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JCdMNbzy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z8iwL79U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_g7RfdtZp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rby2dyyB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kXMMsB9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gjFT9lKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lG9udxig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rXcwV9a8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xZIBwJDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y9rEmtDl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uY5aM5MG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3QLHMHDx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bfwc6Ki0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wt2UsAvq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Wyr34d3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_peLzTLHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hNIJjEkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OWh5dvy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DDorI2lS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yL2qEAlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qhAy5xp3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_La33VXwO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fnoVb4tB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kQf6I9Zb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ivB0vOWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HyyG5AKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_27iZROA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M5va3GKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dbit9BPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GM4H9Og9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WSms5Tx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bDliGFjH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZYqqG8H1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6Vo8Ey9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uivRxPBv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Olsnmm9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4Y2wbZNW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VsYHFMYz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_F6PSKYOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_edUAB8lX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yjpLLoRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fn3MOyWk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6ViAls5c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_weFnmyle_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AvPirAeT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s16wbJ93_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wg6Ad5S5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hpR9InuA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_si5CMLr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nWFSpBoj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z2WLnQkB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6uwKeDnA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zf21diCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vLMZza5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i1yQLGB6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xzmkbixM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FzdO5FLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BRw8hG3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_grIspvNi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AoO5nz9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2b1Lea4Q_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_oB76Uuuj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XTVk1tW8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fMGnNYV0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QZYHA68g_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_YX4rUNiV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_loRgjkXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CW6y0h9r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8ZUDEK7s_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_fJkxBHlP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wWIchYJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Oads15nR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NTfmLqy7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5ju8dpjQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pEKflCfs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_1bko4j9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1S323W4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_64A90bl2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yLKZGatM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SIjaGkfp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NuAZSmzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a67sCqRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ICTZmvG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_WGQCkhdE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3NDorEGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wZvMSDqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n61hkIw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EZsFFaX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T7uAghuh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_g8cSDs5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BD3pOE9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_azZdCb99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JOd40KwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NNolgumO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8FAU8nU4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P2GxwYI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5ffUoVmn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0MltcsAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NBFyLZdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BI3uX2N2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o9DNprA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NZ6T1PeN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NIhv97ZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Ovu0JXh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L5YRkXuz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DZgGFVyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8oqguZlG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WhQSiOIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CHERgUL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G4nvpY7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_n9jQ3fKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_KI5IRohg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gzCGNskV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8lA6zB1A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L9exuBBI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZFmyreN2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z8bMR3us_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bQ59vmWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s0QfGTmM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MXHpAI6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uHQQxnYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oS0A87hE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fP6JUiPq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nHBNCD5H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P9LFvYAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9KwZJJcT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AAQfjHzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_01vVCokl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TEpoJvTh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MACfIwmr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A4LIKLs4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yTDrVZzz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_92PYQKyX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CWOdWZ9m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BfuDWlDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YyhtOEmZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pdjs40ER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aWVMWMm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XbV2Micu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FvWxGg4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_C4USOTFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oc7hroQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hm0E9vSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Iif20k1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AYArvYD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qzuUf9G3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CU9qbPID_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_owVi648a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4hlLOovk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MR0Ci0nS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RvoKAuUQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IuUz1uPD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_32USHc9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XNLddVoR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_swjIorel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Prlir3SF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_211n0fkw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_q4ByJEJI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kuvmLEwl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BLANS34j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W2iuzbs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TLQu0Ask_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HZsxsYOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CvRyCmHR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hucaUfRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lrPb8Hx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wCPES3vG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6d8NxSer_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DBWXnDG2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aP4jdF2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Otk2kYWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HQvZEO1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_my2c2gkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IdBZcTXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dlbPlh9i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pCDBy11U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SjL1bDaL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2L6crxKY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WMzFJsqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_20PYJAIL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FtGgV9Su_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QlKPYnin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CCzPPjX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R6z77Tdj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yoVM9C4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9MHMlXru_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wFlKiZIz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yoMqHYlj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E4J3xZGO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aglGqlvc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_bdPb6GBE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MYco9EAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yBfSi1FO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cCJQMStx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sRB0XdGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vLhdccj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Qt1ESA9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pgMJzfSt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GR1AMHl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nFWWXgXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5WprGXJ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uKLxTk9b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zZwxuAM0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_USrBlXX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BSVUEZEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8Og9XRkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1qkDaioz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I39WajQc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eXXUipi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OD2dOMSa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QTnhJZAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hPDZGLxI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LCcGzekS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M6ATreSB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9YxUAOFz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fELeRnJc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OpgNg3cD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8kxI1Rw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jszTXtuJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_N6B5UkPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OKvPn8Wb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WczFlzIR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KsdgCMa1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0zAV4y15_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YrWP05XV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_THZJhyVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DMAoTHsp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7xnL1wI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UFM3rniq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3lD9gzkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3ZR5xXQj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t0E10vPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4ekeLAJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5IQQAoeW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ah7uDOO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DIoIHlxJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ElxsqPkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FI3oFEdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y7hFSkce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nx7QWfmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z7YHYgB9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jUCjBuox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fiBVurhu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bb4wdtfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yYdbVtbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QzK1BL8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qq6PpzQ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IeOteQtC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_C1YR9VZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6PtSeMCw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Xz4sY8b8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XMpNV7h4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TeAEe0F6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wB6FtzWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_35tFH93F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LMBhFWPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nKrcpwJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eL5UpPA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CyIPNZnn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KnUhVuva_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E8HWyZIR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CcKOI09A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sM0jt2on_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VdEnhOpT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mZuJv9Ws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_md8ci7vd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qfuVgORp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A7ZK7D4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8FNXnwR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aLeJRct2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LA3kgGkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2zXnngpU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0tsRchWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0d2OE5gF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JNRuM1eh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TkBu4xYN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gmYhvx31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V3asV2gx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_auBA7b2w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zeTm68vJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m65L0HbI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fOWvZXq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t2fnhTHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_14oaH5PN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9yole5f0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cSB4ykc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Q8Fi83x9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FzE2DD29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KMSmJF6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dOLSP4GH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yBkHs461_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vFDCuxtg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dxoj6mNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RqVpmlOa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TkI0IbUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q7aP9Y0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_srm629WX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1gBKGqpF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4yHU3RIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_urwjLQcM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bJYf8v58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aqgBsu19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Afyw3eLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8pDG7Igo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SSC9qSHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gQgxfpcI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MJNTmBvk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZpgMK1yA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rNmPu0gJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KIvkkBgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9KhVhzOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iXt64Hxn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kWDO7OOP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WN1OVwBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_suxfN32j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bAngISnm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JqK2VN0S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JUDxKwVB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6blHE8co_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xwUsuzqK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VNLWPOvp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tGQupsC7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qqiFlhV4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_md3gaH5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JdCNHBjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MpLjkerC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_E8oA6SC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aG8zIs03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Kw6QIC9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_l46epTcq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AgwGG9VX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uCtaIUGc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hA3ddixc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Cl0frhAj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_coOBIajW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iZsjjIQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zyB1gCY9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EzGxlyAM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aJPNfcKv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RVsfTwUX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5k9K94Gg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0EjToQtb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lQOjeLrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GZ4uyLEK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Zzfx2NOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lXv1uEpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bj6WRlHQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VWMP3SLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TodGaHMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FkrVSsN8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_C6jHmold_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xk54Bedr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vbfu18v7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7k72xhsk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6ffatlCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dpQ9zChU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Ju2gur8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f8mRk0fj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kd1OJNYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VzTpi4Jq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lkX0Vj6z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_32TOtWJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m96VvKc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mgheyfl5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SwgM1h9H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q38nR67w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QnKLsWAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cK2mrvSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NrAVmnNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fjP5JPFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cxi4pVzo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NLCEUfgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UvXTx0p9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_loXEDleK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KheTrfAa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n5mjr5hT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GGAP2qxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gv3HdWnu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Om9ZP0QC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wMoAalii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0NVpk27E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V9OjJmIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jFtZQDtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CQsWp4Xj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PUkj6WYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bv5rZl26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mATchStj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_imxcPRlB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wDDzT83K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2dPZwh6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L2IEn69a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sSSwk7jw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4GL1MDyn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vP28QwYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wf7jiLPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bPdigsa3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Th0eommj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_he6NEH06_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kWqoe8DU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FPwBiwtb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Pr5cS7Pa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Q7TU1WBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xiPnIJJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XtBFOCFx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9VjZRznF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tnv8MPjH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z5kSGmZ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_wVduZWjV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_sDVvzBoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3bEiY3Y4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_50ry3Z1k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0UKf31bm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LwlhxKRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zk2PDfJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jDQMYAPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iq9CIgCo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xSKtjQI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AQNeiPsh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xSMRQzss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fxZmkDeh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ilUuHvL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bwXPYkin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m4B4LPAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rbY0J7Ai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dltWdryT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HdVlMar2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AgeEnjYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KQSIogaI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I0duw0Gt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gekVcHVN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lcPim6JN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TLa3ip2M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uSAUsmGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZDJLtLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lvveqj3H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RWGO6O7S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_clI4AXyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m4zOQfT2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YI5YVNVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q83lbYEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SrHA7iok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hNeq7TDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cFxeoEca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ujHpQuNV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_puKyHQjv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3z3WnQz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FAO74HyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L108jrwD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6AvtYoCe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KgdPkxst_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_00i3hwXf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_izb6jp3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Udgr4W0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IwXtE6ls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p4B0AAy2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TdGBViL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_356xZB72_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_awNdtf0f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nqvEPnsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_INhcdyFL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XGQvPVJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kRWnhK43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tBwCerr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mm5I8rGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HFZKw2Eo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FDCOTFVf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZkWD2oUk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nEXEerGz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_obLQW7kt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eOsjI4dH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uDfteoLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hnjpzGHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S7FMug0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nBuTVphm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G1AxWbkz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SLcYWcra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fa4U28tJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dO9OfqD6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XhBrYNVS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2mJkzTIh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GIRnLQXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OZ7ifdux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wRqlpOVB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S9eSWjgL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3l44F52I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dhDIWFAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5oD76EdM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uIkTEGEw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MqX08dnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z2IAQkWH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xkMVx5bF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_llN1v8U4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SsdXK3Df_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eJYh2GGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cTXxyfTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1U45GwyE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_isDF02cT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oYB7YQC9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HJx89Vey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q56hsLrD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rq7JqrGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GNFcqJzI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xJ6HsYdk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KjilWNvV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AI94Sn9i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sWv9DCMK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q6LOiMhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ulkif51k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_i95C4GMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_khBdbFRa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7pkxf6Ur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0sqQE4zp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ForQlcK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B3mzbGBe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bzGI38wL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MMg1mQEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jHVUOC8o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ziXO4ABH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_yyAwZJWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_52NZlhlW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AEQ5jHiF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vkb4wKOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WPs7qsHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mXErZxjH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9DRKtcV8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZNCwMNfx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ahjjyo7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XkdmSNQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Etm8XjvK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GqhOAbqV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rv4RHG2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9Y7INKoL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2lyLjGuh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oENBPccu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kuQYi7aY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GiEZ3DhE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lnYOYWrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_b4V1krvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KsFxmWEr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xn2EZ5Gk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EhO58oqs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3CqTwQRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_G15bxr9N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZQB2pfX9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5Du7pEyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GzCO6Ln6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_L052lmIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EOR9wv7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Iu2NdJ8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xQdLNS2O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IK8U8HpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8XWwscef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_n13rJuj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UPgMZivY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_U23Ojk1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JawAijLi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AM5N3Zy1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LCc2L5V1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MUkVcVCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aPb7YcJG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cMJevt1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Raoxc9HE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5KzBaSQW_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_QfGXxSFS;
  SignalLine sLine_smmF09l7;
  SignalLine sLine_qIngFiam;
  SignalLine sLine_0xME2TUq;
  SignalLine sLine_NHAbj9xM;
  SignalBiquad sBiquad_s_XUSch42Z;
  SignalLine sLine_fZHoWUL1;
  SignalLine sLine_vp57NZsc;
  SignalLine sLine_LrkF5UON;
  SignalLine sLine_nKGuUzGg;
  SignalBiquad sBiquad_s_SCKUsQW5;
  SignalLine sLine_hZndcuK2;
  SignalLine sLine_jmjknroU;
  SignalLine sLine_T7FpAd0z;
  SignalLine sLine_ZByKFldF;
  SignalLine sLine_0MZbKAk5;
  SignalBiquad sBiquad_s_EtFzUE8T;
  SignalLine sLine_EVVK5FiP;
  SignalLine sLine_bJsh7miV;
  SignalLine sLine_Z4PoDuAR;
  SignalLine sLine_sOLsYpch;
  SignalLine sLine_s3HqKmzu;
  SignalBiquad sBiquad_s_mM3O0BVI;
  SignalLine sLine_H03pO37L;
  SignalLine sLine_KJ5viBBS;
  SignalLine sLine_GVQKD24T;
  SignalLine sLine_VaJiV5gc;
  SignalBiquad sBiquad_s_8LyX5g46;
  SignalLine sLine_2Wm7w12W;
  SignalLine sLine_JkSEu3uQ;
  SignalLine sLine_hmM1f5rH;
  SignalLine sLine_hpdru6Xd;
  SignalLine sLine_USJljXyD;
  SignalBiquad sBiquad_s_3884Ebxj;
  ControlVar cVar_Nj7A0jXI;
  ControlVar cVar_1ApRwfO8;
  ControlVar cVar_Eb40xFpb;
  ControlVar cVar_5mkpxFet;
  ControlSlice cSlice_LpMxryyD;
  ControlVar cVar_n06GRgYT;
  ControlVar cVar_JssBPvCQ;
  ControlIf cIf_V83rdlK4;
  ControlIf cIf_K4zMT0tA;
  ControlBinop cBinop_7sg2keBw;
  ControlBinop cBinop_AH8GkEYl;
  ControlBinop cBinop_wzbarDCW;
  ControlBinop cBinop_qityjlOF;
  ControlBinop cBinop_z8iwL79U;
  ControlIf cIf_g7RfdtZp;
  ControlBinop cBinop_Rby2dyyB;
  ControlBinop cBinop_kXMMsB9v;
  ControlBinop cBinop_lG9udxig;
  ControlBinop cBinop_rXcwV9a8;
  ControlBinop cBinop_xZIBwJDb;
  ControlVar cVar_wt2UsAvq;
  ControlIf cIf_Wyr34d3G;
  ControlIf cIf_peLzTLHC;
  ControlBinop cBinop_OWh5dvy9;
  ControlBinop cBinop_DDorI2lS;
  ControlBinop cBinop_La33VXwO;
  ControlBinop cBinop_fnoVb4tB;
  ControlBinop cBinop_ivB0vOWu;
  ControlIf cIf_HyyG5AKH;
  ControlBinop cBinop_27iZROA6;
  ControlBinop cBinop_M5va3GKF;
  ControlBinop cBinop_GM4H9Og9;
  ControlBinop cBinop_WSms5Tx5;
  ControlBinop cBinop_bDliGFjH;
  ControlVar cVar_4Y2wbZNW;
  ControlIf cIf_VsYHFMYz;
  ControlIf cIf_F6PSKYOb;
  ControlBinop cBinop_yjpLLoRp;
  ControlBinop cBinop_fn3MOyWk;
  ControlBinop cBinop_AvPirAeT;
  ControlBinop cBinop_s16wbJ93;
  ControlBinop cBinop_hpR9InuA;
  ControlIf cIf_si5CMLr5;
  ControlBinop cBinop_nWFSpBoj;
  ControlBinop cBinop_Z2WLnQkB;
  ControlBinop cBinop_Zf21diCN;
  ControlBinop cBinop_vLMZza5K;
  ControlBinop cBinop_i1yQLGB6;
  ControlIf cIf_AoO5nz9A;
  ControlSlice cSlice_oB76Uuuj;
  ControlVar cVar_XTVk1tW8;
  ControlSlice cSlice_YX4rUNiV;
  ControlVar cVar_loRgjkXF;
  ControlSlice cSlice_fJkxBHlP;
  ControlVar cVar_wWIchYJP;
  ControlSlice cSlice_5ju8dpjQ;
  ControlVar cVar_pEKflCfs;
  ControlBinop cBinop_wZvMSDqR;
  ControlBinop cBinop_EZsFFaX4;
  ControlBinop cBinop_T7uAghuh;
  ControlBinop cBinop_azZdCb99;
  ControlBinop cBinop_JOd40KwN;
  ControlBinop cBinop_NNolgumO;
  ControlBinop cBinop_8FAU8nU4;
  ControlBinop cBinop_P2GxwYI1;
  ControlVar cVar_5ffUoVmn;
  ControlBinop cBinop_0MltcsAn;
  ControlBinop cBinop_NBFyLZdH;
  ControlBinop cBinop_BI3uX2N2;
  ControlBinop cBinop_o9DNprA9;
  ControlBinop cBinop_NZ6T1PeN;
  ControlBinop cBinop_NIhv97ZB;
  ControlBinop cBinop_4Ovu0JXh;
  ControlBinop cBinop_DZgGFVyK;
  ControlVar cVar_8oqguZlG;
  ControlVar cVar_WhQSiOIf;
  ControlBinop cBinop_L9exuBBI;
  ControlBinop cBinop_ZFmyreN2;
  ControlBinop cBinop_Z8bMR3us;
  ControlBinop cBinop_s0QfGTmM;
  ControlBinop cBinop_MXHpAI6g;
  ControlBinop cBinop_uHQQxnYv;
  ControlBinop cBinop_oS0A87hE;
  ControlBinop cBinop_fP6JUiPq;
  ControlBinop cBinop_nHBNCD5H;
  ControlBinop cBinop_Hm0E9vSe;
  ControlBinop cBinop_AYArvYD5;
  ControlBinop cBinop_qzuUf9G3;
  ControlBinop cBinop_4hlLOovk;
  ControlBinop cBinop_MR0Ci0nS;
  ControlBinop cBinop_RvoKAuUQ;
  ControlBinop cBinop_IuUz1uPD;
  ControlBinop cBinop_32USHc9c;
  ControlBinop cBinop_XNLddVoR;
  ControlBinop cBinop_swjIorel;
  ControlBinop cBinop_211n0fkw;
  ControlVar cVar_q4ByJEJI;
  ControlVar cVar_kuvmLEwl;
  ControlVar cVar_BLANS34j;
  ControlBinop cBinop_wCPES3vG;
  ControlBinop cBinop_6d8NxSer;
  ControlBinop cBinop_DBWXnDG2;
  ControlBinop cBinop_Otk2kYWV;
  ControlBinop cBinop_HQvZEO1E;
  ControlBinop cBinop_my2c2gkv;
  ControlBinop cBinop_IdBZcTXr;
  ControlBinop cBinop_dlbPlh9i;
  ControlBinop cBinop_yBfSi1FO;
  ControlBinop cBinop_sRB0XdGK;
  ControlBinop cBinop_vLhdccj6;
  ControlBinop cBinop_GR1AMHl0;
  ControlBinop cBinop_nFWWXgXp;
  ControlBinop cBinop_5WprGXJ7;
  ControlBinop cBinop_uKLxTk9b;
  ControlBinop cBinop_zZwxuAM0;
  ControlBinop cBinop_BSVUEZEC;
  ControlBinop cBinop_1qkDaioz;
  ControlBinop cBinop_I39WajQc;
  ControlBinop cBinop_OD2dOMSa;
  ControlBinop cBinop_QTnhJZAy;
  ControlBinop cBinop_hPDZGLxI;
  ControlBinop cBinop_M6ATreSB;
  ControlVar cVar_9YxUAOFz;
  ControlVar cVar_fELeRnJc;
  ControlVar cVar_OpgNg3cD;
  ControlBinop cBinop_0zAV4y15;
  ControlBinop cBinop_YrWP05XV;
  ControlBinop cBinop_THZJhyVc;
  ControlBinop cBinop_7xnL1wI0;
  ControlBinop cBinop_UFM3rniq;
  ControlBinop cBinop_3lD9gzkC;
  ControlBinop cBinop_3ZR5xXQj;
  ControlBinop cBinop_t0E10vPf;
  ControlBinop cBinop_4ekeLAJZ;
  ControlBinop cBinop_Bb4wdtfa;
  ControlBinop cBinop_QzK1BL8a;
  ControlBinop cBinop_Qq6PpzQ2;
  SignalVarf sVarf_fdwgQdr4;
  SignalVarf sVarf_W2uVrAZj;
  SignalVarf sVarf_dGbVYz7D;
  ControlSlice cSlice_C1YR9VZT;
  ControlVar cVar_6PtSeMCw;
  ControlVar cVar_XMpNV7h4;
  ControlIf cIf_TeAEe0F6;
  ControlIf cIf_wB6FtzWN;
  ControlBinop cBinop_LMBhFWPT;
  ControlBinop cBinop_nKrcpwJv;
  ControlBinop cBinop_KnUhVuva;
  ControlBinop cBinop_E8HWyZIR;
  ControlBinop cBinop_sM0jt2on;
  ControlIf cIf_VdEnhOpT;
  ControlBinop cBinop_mZuJv9Ws;
  ControlBinop cBinop_md8ci7vd;
  ControlBinop cBinop_A7ZK7D4K;
  ControlBinop cBinop_8FNXnwR2;
  ControlBinop cBinop_aLeJRct2;
  ControlVar cVar_JNRuM1eh;
  ControlIf cIf_TkBu4xYN;
  ControlIf cIf_gmYhvx31;
  ControlBinop cBinop_auBA7b2w;
  ControlBinop cBinop_zeTm68vJ;
  ControlBinop cBinop_t2fnhTHf;
  ControlBinop cBinop_14oaH5PN;
  ControlBinop cBinop_cSB4ykc9;
  ControlIf cIf_Q8Fi83x9;
  ControlBinop cBinop_FzE2DD29;
  ControlBinop cBinop_KMSmJF6J;
  ControlBinop cBinop_yBkHs461;
  ControlBinop cBinop_vFDCuxtg;
  ControlBinop cBinop_dxoj6mNI;
  ControlVar cVar_1gBKGqpF;
  ControlIf cIf_4yHU3RIp;
  ControlIf cIf_urwjLQcM;
  ControlBinop cBinop_aqgBsu19;
  ControlBinop cBinop_Afyw3eLb;
  ControlBinop cBinop_gQgxfpcI;
  ControlBinop cBinop_MJNTmBvk;
  ControlBinop cBinop_rNmPu0gJ;
  ControlIf cIf_KIvkkBgS;
  ControlBinop cBinop_9KhVhzOm;
  ControlBinop cBinop_iXt64Hxn;
  ControlBinop cBinop_WN1OVwBi;
  ControlBinop cBinop_suxfN32j;
  ControlBinop cBinop_bAngISnm;
  ControlIf cIf_VNLWPOvp;
  ControlSlice cSlice_qqiFlhV4;
  ControlVar cVar_md3gaH5s;
  ControlSlice cSlice_E8oA6SC0;
  ControlVar cVar_aG8zIs03;
  ControlSlice cSlice_AgwGG9VX;
  ControlVar cVar_uCtaIUGc;
  ControlSlice cSlice_coOBIajW;
  ControlVar cVar_iZsjjIQh;
  ControlBinop cBinop_bj6WRlHQ;
  ControlBinop cBinop_TodGaHMC;
  ControlBinop cBinop_FkrVSsN8;
  ControlBinop cBinop_vbfu18v7;
  ControlBinop cBinop_7k72xhsk;
  ControlBinop cBinop_6ffatlCj;
  ControlBinop cBinop_dpQ9zChU;
  ControlBinop cBinop_9Ju2gur8;
  ControlVar cVar_f8mRk0fj;
  ControlBinop cBinop_kd1OJNYR;
  ControlBinop cBinop_VzTpi4Jq;
  ControlBinop cBinop_lkX0Vj6z;
  ControlBinop cBinop_32TOtWJV;
  ControlBinop cBinop_m96VvKc1;
  ControlBinop cBinop_Mgheyfl5;
  ControlBinop cBinop_SwgM1h9H;
  ControlBinop cBinop_QnKLsWAN;
  ControlVar cVar_cK2mrvSJ;
  ControlVar cVar_NrAVmnNQ;
  ControlBinop cBinop_n5mjr5hT;
  ControlBinop cBinop_GGAP2qxN;
  ControlBinop cBinop_Gv3HdWnu;
  ControlBinop cBinop_wMoAalii;
  ControlBinop cBinop_0NVpk27E;
  ControlBinop cBinop_V9OjJmIn;
  ControlBinop cBinop_jFtZQDtp;
  ControlBinop cBinop_CQsWp4Xj;
  ControlBinop cBinop_PUkj6WYG;
  ControlBinop cBinop_XtBFOCFx;
  ControlBinop cBinop_tnv8MPjH;
  ControlBinop cBinop_Z5kSGmZ1;
  ControlBinop cBinop_3bEiY3Y4;
  ControlBinop cBinop_50ry3Z1k;
  ControlBinop cBinop_0UKf31bm;
  ControlBinop cBinop_LwlhxKRX;
  ControlBinop cBinop_zk2PDfJq;
  ControlBinop cBinop_jDQMYAPa;
  ControlBinop cBinop_iq9CIgCo;
  ControlBinop cBinop_AQNeiPsh;
  ControlVar cVar_xSMRQzss;
  ControlVar cVar_fxZmkDeh;
  ControlVar cVar_ilUuHvL3;
  ControlBinop cBinop_KQSIogaI;
  ControlBinop cBinop_I0duw0Gt;
  ControlBinop cBinop_gekVcHVN;
  ControlBinop cBinop_TLa3ip2M;
  ControlBinop cBinop_uSAUsmGC;
  ControlBinop cBinop_qZDJLtLf;
  ControlBinop cBinop_lvveqj3H;
  ControlBinop cBinop_RWGO6O7S;
  ControlBinop cBinop_IwXtE6ls;
  ControlBinop cBinop_TdGBViL7;
  ControlBinop cBinop_356xZB72;
  ControlBinop cBinop_INhcdyFL;
  ControlBinop cBinop_XGQvPVJV;
  ControlBinop cBinop_kRWnhK43;
  ControlBinop cBinop_tBwCerr5;
  ControlBinop cBinop_mm5I8rGN;
  ControlBinop cBinop_FDCOTFVf;
  ControlBinop cBinop_nEXEerGz;
  ControlBinop cBinop_obLQW7kt;
  ControlBinop cBinop_uDfteoLC;
  ControlBinop cBinop_hnjpzGHx;
  ControlBinop cBinop_S7FMug0L;
  ControlBinop cBinop_G1AxWbkz;
  ControlVar cVar_SLcYWcra;
  ControlVar cVar_fa4U28tJ;
  ControlVar cVar_dO9OfqD6;
  ControlBinop cBinop_3l44F52I;
  ControlBinop cBinop_dhDIWFAd;
  ControlBinop cBinop_5oD76EdM;
  ControlBinop cBinop_MqX08dnF;
  ControlBinop cBinop_Z2IAQkWH;
  ControlBinop cBinop_xkMVx5bF;
  ControlBinop cBinop_llN1v8U4;
  ControlBinop cBinop_SsdXK3Df;
  ControlBinop cBinop_eJYh2GGd;
  ControlBinop cBinop_AI94Sn9i;
  ControlBinop cBinop_q6LOiMhL;
  ControlBinop cBinop_ulkif51k;
  SignalVarf sVarf_5mOXxqVA;
  SignalVarf sVarf_u2Gj6A5e;
  SignalVarf sVarf_j7lQpyvy;
  ControlVar cVar_i95C4GMz;
  ControlVar cVar_khBdbFRa;
  ControlBinop cBinop_MMg1mQEl;
  ControlBinop cBinop_jHVUOC8o;
  ControlBinop cBinop_ziXO4ABH;
  ControlBinop cBinop_52NZlhlW;
  ControlBinop cBinop_AEQ5jHiF;
  ControlBinop cBinop_Vkb4wKOW;
  ControlBinop cBinop_WPs7qsHu;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
