/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_QfGXxSFS);
  numBytes += sLine_init(&sLine_smmF09l7);
  numBytes += sLine_init(&sLine_qIngFiam);
  numBytes += sLine_init(&sLine_0xME2TUq);
  numBytes += sLine_init(&sLine_NHAbj9xM);
  numBytes += sBiquad_init(&sBiquad_s_XUSch42Z);
  numBytes += sLine_init(&sLine_fZHoWUL1);
  numBytes += sLine_init(&sLine_vp57NZsc);
  numBytes += sLine_init(&sLine_LrkF5UON);
  numBytes += sLine_init(&sLine_nKGuUzGg);
  numBytes += sBiquad_init(&sBiquad_s_SCKUsQW5);
  numBytes += sLine_init(&sLine_hZndcuK2);
  numBytes += sLine_init(&sLine_jmjknroU);
  numBytes += sLine_init(&sLine_T7FpAd0z);
  numBytes += sLine_init(&sLine_ZByKFldF);
  numBytes += sLine_init(&sLine_0MZbKAk5);
  numBytes += sBiquad_init(&sBiquad_s_EtFzUE8T);
  numBytes += sLine_init(&sLine_EVVK5FiP);
  numBytes += sLine_init(&sLine_bJsh7miV);
  numBytes += sLine_init(&sLine_Z4PoDuAR);
  numBytes += sLine_init(&sLine_sOLsYpch);
  numBytes += sLine_init(&sLine_s3HqKmzu);
  numBytes += sBiquad_init(&sBiquad_s_mM3O0BVI);
  numBytes += sLine_init(&sLine_H03pO37L);
  numBytes += sLine_init(&sLine_KJ5viBBS);
  numBytes += sLine_init(&sLine_GVQKD24T);
  numBytes += sLine_init(&sLine_VaJiV5gc);
  numBytes += sBiquad_init(&sBiquad_s_8LyX5g46);
  numBytes += sLine_init(&sLine_2Wm7w12W);
  numBytes += sLine_init(&sLine_JkSEu3uQ);
  numBytes += sLine_init(&sLine_hmM1f5rH);
  numBytes += sLine_init(&sLine_hpdru6Xd);
  numBytes += sLine_init(&sLine_USJljXyD);
  numBytes += sBiquad_init(&sBiquad_s_3884Ebxj);
  numBytes += cVar_init_f(&cVar_Nj7A0jXI, 0.0f);
  numBytes += cVar_init_f(&cVar_1ApRwfO8, 0.0f);
  numBytes += cVar_init_f(&cVar_Eb40xFpb, 0.0f);
  numBytes += cVar_init_f(&cVar_5mkpxFet, 0.0f);
  numBytes += cSlice_init(&cSlice_LpMxryyD, 1, -1);
  numBytes += cVar_init_f(&cVar_n06GRgYT, 1337.0f);
  numBytes += cVar_init_f(&cVar_JssBPvCQ, 0.0f);
  numBytes += cIf_init(&cIf_V83rdlK4, false);
  numBytes += cIf_init(&cIf_K4zMT0tA, false);
  numBytes += cBinop_init(&cBinop_7sg2keBw, 0.0f); // __pow
  numBytes += cIf_init(&cIf_g7RfdtZp, false);
  numBytes += cBinop_init(&cBinop_lG9udxig, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_rXcwV9a8, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_xZIBwJDb, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_wt2UsAvq, 0.0f);
  numBytes += cIf_init(&cIf_Wyr34d3G, false);
  numBytes += cIf_init(&cIf_peLzTLHC, false);
  numBytes += cBinop_init(&cBinop_OWh5dvy9, 0.0f); // __pow
  numBytes += cIf_init(&cIf_HyyG5AKH, false);
  numBytes += cBinop_init(&cBinop_GM4H9Og9, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_WSms5Tx5, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_bDliGFjH, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_4Y2wbZNW, 0.0f);
  numBytes += cIf_init(&cIf_VsYHFMYz, false);
  numBytes += cIf_init(&cIf_F6PSKYOb, false);
  numBytes += cBinop_init(&cBinop_yjpLLoRp, 0.0f); // __pow
  numBytes += cIf_init(&cIf_si5CMLr5, false);
  numBytes += cBinop_init(&cBinop_Zf21diCN, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_vLMZza5K, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_i1yQLGB6, -15.0f); // __eq
  numBytes += cIf_init(&cIf_AoO5nz9A, false);
  numBytes += cSlice_init(&cSlice_oB76Uuuj, 1, -1);
  numBytes += cVar_init_f(&cVar_XTVk1tW8, 0.0f);
  numBytes += cSlice_init(&cSlice_YX4rUNiV, 1, -1);
  numBytes += cVar_init_f(&cVar_loRgjkXF, 0.0f);
  numBytes += cSlice_init(&cSlice_fJkxBHlP, 1, -1);
  numBytes += cVar_init_f(&cVar_wWIchYJP, 0.0f);
  numBytes += cSlice_init(&cSlice_5ju8dpjQ, 1, -1);
  numBytes += cVar_init_f(&cVar_pEKflCfs, 0.313f);
  numBytes += cBinop_init(&cBinop_EZsFFaX4, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_T7uAghuh, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_5ffUoVmn, 0.0f);
  numBytes += cVar_init_f(&cVar_8oqguZlG, 1337.0f);
  numBytes += cVar_init_f(&cVar_WhQSiOIf, 0.3f);
  numBytes += cBinop_init(&cBinop_ZFmyreN2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MXHpAI6g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uHQQxnYv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oS0A87hE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fP6JUiPq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nHBNCD5H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AYArvYD5, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_qzuUf9G3, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_q4ByJEJI, 0.0f);
  numBytes += cVar_init_f(&cVar_kuvmLEwl, 1337.0f);
  numBytes += cVar_init_f(&cVar_BLANS34j, 0.313f);
  numBytes += cBinop_init(&cBinop_6d8NxSer, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HQvZEO1E, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_my2c2gkv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IdBZcTXr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dlbPlh9i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sRB0XdGK, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_vLhdccj6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_9YxUAOFz, 0.0f);
  numBytes += cVar_init_f(&cVar_fELeRnJc, 1037.0f);
  numBytes += cVar_init_f(&cVar_OpgNg3cD, 0.4f);
  numBytes += cBinop_init(&cBinop_YrWP05XV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UFM3rniq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3lD9gzkC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3ZR5xXQj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_t0E10vPf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4ekeLAJZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fdwgQdr4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_W2uVrAZj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dGbVYz7D, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_C1YR9VZT, 1, -1);
  numBytes += cVar_init_f(&cVar_6PtSeMCw, 1337.0f);
  numBytes += cVar_init_f(&cVar_XMpNV7h4, 0.0f);
  numBytes += cIf_init(&cIf_TeAEe0F6, false);
  numBytes += cIf_init(&cIf_wB6FtzWN, false);
  numBytes += cBinop_init(&cBinop_LMBhFWPT, 0.0f); // __pow
  numBytes += cIf_init(&cIf_VdEnhOpT, false);
  numBytes += cBinop_init(&cBinop_A7ZK7D4K, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_8FNXnwR2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_aLeJRct2, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_JNRuM1eh, 0.0f);
  numBytes += cIf_init(&cIf_TkBu4xYN, false);
  numBytes += cIf_init(&cIf_gmYhvx31, false);
  numBytes += cBinop_init(&cBinop_auBA7b2w, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Q8Fi83x9, false);
  numBytes += cBinop_init(&cBinop_yBkHs461, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_vFDCuxtg, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_dxoj6mNI, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_1gBKGqpF, 0.0f);
  numBytes += cIf_init(&cIf_4yHU3RIp, false);
  numBytes += cIf_init(&cIf_urwjLQcM, false);
  numBytes += cBinop_init(&cBinop_aqgBsu19, 0.0f); // __pow
  numBytes += cIf_init(&cIf_KIvkkBgS, false);
  numBytes += cBinop_init(&cBinop_WN1OVwBi, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_suxfN32j, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_bAngISnm, -15.0f); // __eq
  numBytes += cIf_init(&cIf_VNLWPOvp, false);
  numBytes += cSlice_init(&cSlice_qqiFlhV4, 1, -1);
  numBytes += cVar_init_f(&cVar_md3gaH5s, 0.0f);
  numBytes += cSlice_init(&cSlice_E8oA6SC0, 1, -1);
  numBytes += cVar_init_f(&cVar_aG8zIs03, 0.0f);
  numBytes += cSlice_init(&cSlice_AgwGG9VX, 1, -1);
  numBytes += cVar_init_f(&cVar_uCtaIUGc, 0.0f);
  numBytes += cSlice_init(&cSlice_coOBIajW, 1, -1);
  numBytes += cVar_init_f(&cVar_iZsjjIQh, 0.313f);
  numBytes += cBinop_init(&cBinop_TodGaHMC, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FkrVSsN8, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_f8mRk0fj, 0.0f);
  numBytes += cVar_init_f(&cVar_cK2mrvSJ, 1337.0f);
  numBytes += cVar_init_f(&cVar_NrAVmnNQ, 0.3f);
  numBytes += cBinop_init(&cBinop_GGAP2qxN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0NVpk27E, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V9OjJmIn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jFtZQDtp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CQsWp4Xj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PUkj6WYG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tnv8MPjH, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Z5kSGmZ1, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xSMRQzss, 0.0f);
  numBytes += cVar_init_f(&cVar_fxZmkDeh, 1337.0f);
  numBytes += cVar_init_f(&cVar_ilUuHvL3, 0.313f);
  numBytes += cBinop_init(&cBinop_I0duw0Gt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uSAUsmGC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qZDJLtLf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lvveqj3H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RWGO6O7S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TdGBViL7, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_356xZB72, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_SLcYWcra, 0.0f);
  numBytes += cVar_init_f(&cVar_fa4U28tJ, 1037.0f);
  numBytes += cVar_init_f(&cVar_dO9OfqD6, 0.4f);
  numBytes += cBinop_init(&cBinop_dhDIWFAd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Z2IAQkWH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xkMVx5bF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_llN1v8U4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SsdXK3Df, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eJYh2GGd, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5mOXxqVA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_u2Gj6A5e, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_j7lQpyvy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_i95C4GMz, 5705.6f);
  numBytes += cVar_init_f(&cVar_khBdbFRa, 313.3f);
  numBytes += cBinop_init(&cBinop_MMg1mQEl, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_jHVUOC8o, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_ziXO4ABH, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rv4RHG2X_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2lyLjGuh_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9Y7INKoL_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5KzBaSQW_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GiEZ3DhE_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lnYOYWrH_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oENBPccu_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kuQYi7aY_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b4V1krvw_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3CqTwQRX_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EhO58oqs_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xn2EZ5Gk_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5Du7pEyv_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZQB2pfX9_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G15bxr9N_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EOR9wv7x_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_L052lmIw_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GzCO6Ln6_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IK8U8HpD_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8XWwscef_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Iu2NdJ8b_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xQdLNS2O_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n13rJuj1_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JawAijLi_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U23Ojk1v_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UPgMZivY_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MUkVcVCU_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LCc2L5V1_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AM5N3Zy1_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Raoxc9HE_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cMJevt1q_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aPb7YcJG_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KsFxmWEr_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_Nj7A0jXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mXErZxjH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_1ApRwfO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9DRKtcV8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Eb40xFpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZNCwMNfx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_5mkpxFet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ahjjyo7j_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bzGI38wL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ForQlcK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B3mzbGBe_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_99gjPaqI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LpMxryyD, 0, m, &cSlice_LpMxryyD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8ZUDEK7s_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_LpMxryyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ACKcPhZE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ACKcPhZE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_n06GRgYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ACKcPhZE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ACKcPhZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oENBPccu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_JssBPvCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Rby2dyyB_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_V83rdlK4, 0, m, &cIf_V83rdlK4_sendMessage);
}

void Heavy_WSTD_3Q::cIf_V83rdlK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kXMMsB9v_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_K4zMT0tA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_JCdMNbzy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qityjlOF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_LLGGFEcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7sg2keBw, HV_BINOP_POW, 0, m, &cBinop_7sg2keBw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7sg2keBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g7RfdtZp, 0, m, &cIf_g7RfdtZp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AH8GkEYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_z8iwL79U_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dCUXS88c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4zMT0tA, 0, m, &cIf_K4zMT0tA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7zUks9y1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wzbarDCW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wzbarDCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4zMT0tA, 1, m, &cIf_K4zMT0tA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qityjlOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_AH8GkEYl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_JCdMNbzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_g7RfdtZp, 0, m, &cIf_g7RfdtZp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z8iwL79U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7sg2keBw, HV_BINOP_POW, 1, m, &cBinop_7sg2keBw_sendMessage);
  cMsg_LLGGFEcU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_g7RfdtZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_fdwgQdr4, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_Rby2dyyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V83rdlK4, 1, m, &cIf_V83rdlK4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kXMMsB9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXcwV9a8, HV_BINOP_GREATER_THAN, 1, m, &cBinop_rXcwV9a8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xZIBwJDb, HV_BINOP_EQ, 1, m, &cBinop_xZIBwJDb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_gjFT9lKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lG9udxig, HV_BINOP_ADD, 0, m, &cBinop_lG9udxig_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lG9udxig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7zUks9y1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dCUXS88c_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rXcwV9a8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g7RfdtZp, 1, m, &cIf_g7RfdtZp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xZIBwJDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y9rEmtDl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_y9rEmtDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fdwgQdr4, m);
}

void Heavy_WSTD_3Q::cCast_uY5aM5MG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JssBPvCQ, 0, m, &cVar_JssBPvCQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3QLHMHDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lG9udxig, HV_BINOP_ADD, 1, m, &cBinop_lG9udxig_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXcwV9a8, HV_BINOP_GREATER_THAN, 0, m, &cBinop_rXcwV9a8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xZIBwJDb, HV_BINOP_EQ, 0, m, &cBinop_xZIBwJDb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Bfwc6Ki0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gjFT9lKj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_wt2UsAvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_27iZROA6_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Wyr34d3G, 0, m, &cIf_Wyr34d3G_sendMessage);
}

void Heavy_WSTD_3Q::cIf_Wyr34d3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_M5va3GKF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_peLzTLHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kQf6I9Zb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_fnoVb4tB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_hNIJjEkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OWh5dvy9, HV_BINOP_POW, 0, m, &cBinop_OWh5dvy9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OWh5dvy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HyyG5AKH, 0, m, &cIf_HyyG5AKH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DDorI2lS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ivB0vOWu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yL2qEAlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_peLzTLHC, 0, m, &cIf_peLzTLHC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qhAy5xp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_La33VXwO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_La33VXwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_peLzTLHC, 1, m, &cIf_peLzTLHC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fnoVb4tB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_DDorI2lS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_kQf6I9Zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HyyG5AKH, 0, m, &cIf_HyyG5AKH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ivB0vOWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OWh5dvy9, HV_BINOP_POW, 1, m, &cBinop_OWh5dvy9_sendMessage);
  cMsg_hNIJjEkh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_HyyG5AKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Bb4wdtfa_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QzK1BL8a_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Qq6PpzQ2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_27iZROA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wyr34d3G, 1, m, &cIf_Wyr34d3G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_M5va3GKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WSms5Tx5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WSms5Tx5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bDliGFjH, HV_BINOP_EQ, 1, m, &cBinop_bDliGFjH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Dbit9BPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GM4H9Og9, HV_BINOP_ADD, 0, m, &cBinop_GM4H9Og9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GM4H9Og9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qhAy5xp3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yL2qEAlE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WSms5Tx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HyyG5AKH, 1, m, &cIf_HyyG5AKH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bDliGFjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZYqqG8H1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ZYqqG8H1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Bb4wdtfa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QzK1BL8a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Qq6PpzQ2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6Vo8Ey9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dbit9BPr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_uivRxPBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GM4H9Og9, HV_BINOP_ADD, 1, m, &cBinop_GM4H9Og9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WSms5Tx5, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WSms5Tx5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bDliGFjH, HV_BINOP_EQ, 0, m, &cBinop_bDliGFjH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Olsnmm9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wt2UsAvq, 0, m, &cVar_wt2UsAvq_sendMessage);
}

void Heavy_WSTD_3Q::cVar_4Y2wbZNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nWFSpBoj_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VsYHFMYz, 0, m, &cIf_VsYHFMYz_sendMessage);
}

void Heavy_WSTD_3Q::cIf_VsYHFMYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Z2WLnQkB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_F6PSKYOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_wg6Ad5S5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_s16wbJ93_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_edUAB8lX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yjpLLoRp, HV_BINOP_POW, 0, m, &cBinop_yjpLLoRp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yjpLLoRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_si5CMLr5, 0, m, &cIf_si5CMLr5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fn3MOyWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_hpR9InuA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6ViAls5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AvPirAeT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_weFnmyle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F6PSKYOb, 0, m, &cIf_F6PSKYOb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AvPirAeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F6PSKYOb, 1, m, &cIf_F6PSKYOb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_s16wbJ93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_fn3MOyWk_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_wg6Ad5S5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_si5CMLr5, 0, m, &cIf_si5CMLr5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hpR9InuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yjpLLoRp, HV_BINOP_POW, 1, m, &cBinop_yjpLLoRp_sendMessage);
  cMsg_edUAB8lX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_si5CMLr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dGbVYz7D, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_nWFSpBoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VsYHFMYz, 1, m, &cIf_VsYHFMYz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Z2WLnQkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vLMZza5K, HV_BINOP_GREATER_THAN, 1, m, &cBinop_vLMZza5K_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_i1yQLGB6, HV_BINOP_EQ, 1, m, &cBinop_i1yQLGB6_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_6uwKeDnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zf21diCN, HV_BINOP_ADD, 0, m, &cBinop_Zf21diCN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Zf21diCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6ViAls5c_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_weFnmyle_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vLMZza5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_si5CMLr5, 1, m, &cIf_si5CMLr5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_i1yQLGB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xzmkbixM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_xzmkbixM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dGbVYz7D, m);
}

void Heavy_WSTD_3Q::cCast_FzdO5FLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4Y2wbZNW, 0, m, &cVar_4Y2wbZNW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BRw8hG3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6uwKeDnA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_grIspvNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zf21diCN, HV_BINOP_ADD, 1, m, &cBinop_Zf21diCN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vLMZza5K, HV_BINOP_GREATER_THAN, 0, m, &cBinop_vLMZza5K_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_i1yQLGB6, HV_BINOP_EQ, 0, m, &cBinop_i1yQLGB6_sendMessage);
}

void Heavy_WSTD_3Q::cIf_AoO5nz9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_W2uVrAZj, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_2b1Lea4Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oB76Uuuj, 0, m, &cSlice_oB76Uuuj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QZYHA68g_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_oB76Uuuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fMGnNYV0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fMGnNYV0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_XTVk1tW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fMGnNYV0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_fMGnNYV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GiEZ3DhE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_QZYHA68g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YX4rUNiV, 0, m, &cSlice_YX4rUNiV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_99gjPaqI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_YX4rUNiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CW6y0h9r_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CW6y0h9r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_loRgjkXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CW6y0h9r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_CW6y0h9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_b4V1krvw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_8ZUDEK7s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fJkxBHlP, 0, m, &cSlice_fJkxBHlP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NTfmLqy7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_fJkxBHlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Oads15nR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Oads15nR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_wWIchYJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Oads15nR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Oads15nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lnYOYWrH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_NTfmLqy7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5ju8dpjQ, 0, m, &cSlice_5ju8dpjQ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_5ju8dpjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1bko4j9n_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1bko4j9n_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_pEKflCfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1bko4j9n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_1bko4j9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kuQYi7aY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_1S323W4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QfGXxSFS, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_64A90bl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_smmF09l7, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yLKZGatM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qIngFiam, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_SIjaGkfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0xME2TUq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_NuAZSmzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NHAbj9xM, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_a67sCqRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ICTZmvG9_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_ICTZmvG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EZsFFaX4, HV_BINOP_DIVIDE, 1, m, &cBinop_EZsFFaX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n61hkIw3_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_WGQCkhdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_wZvMSDqR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3NDorEGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_WGQCkhdE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wZvMSDqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EZsFFaX4, HV_BINOP_DIVIDE, 0, m, &cBinop_EZsFFaX4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_n61hkIw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3NDorEGD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EZsFFaX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T7uAghuh, HV_BINOP_MULTIPLY, 1, m, &cBinop_T7uAghuh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_T7uAghuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CHERgUL5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G4nvpY7n_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_g8cSDs5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n9jQ3fKt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_BD3pOE9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KI5IRohg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_azZdCb99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_JOd40KwN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JOd40KwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T7uAghuh, HV_BINOP_MULTIPLY, 0, m, &cBinop_T7uAghuh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NNolgumO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8FAU8nU4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8FAU8nU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8lA6zB1A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_P2GxwYI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5ffUoVmn, 1, m, &cVar_5ffUoVmn_sendMessage);
}

void Heavy_WSTD_3Q::cVar_5ffUoVmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bQ59vmWe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_0MltcsAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MXHpAI6g, HV_BINOP_MULTIPLY, 1, m, &cBinop_MXHpAI6g_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NBFyLZdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0MltcsAn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BI3uX2N2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_o9DNprA9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_o9DNprA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHQQxnYv, HV_BINOP_MULTIPLY, 1, m, &cBinop_uHQQxnYv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NZ6T1PeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oS0A87hE, HV_BINOP_MULTIPLY, 1, m, &cBinop_oS0A87hE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NIhv97ZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NZ6T1PeN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4Ovu0JXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fP6JUiPq, HV_BINOP_MULTIPLY, 1, m, &cBinop_fP6JUiPq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_L5YRkXuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DZgGFVyK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DZgGFVyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nHBNCD5H, HV_BINOP_MULTIPLY, 1, m, &cBinop_nHBNCD5H_sendMessage);
}

void Heavy_WSTD_3Q::cVar_8oqguZlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CWOdWZ9m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_azZdCb99_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_92PYQKyX_sendMessage);
}

void Heavy_WSTD_3Q::cVar_WhQSiOIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_NNolgumO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CHERgUL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_g8cSDs5I_sendMessage);
}

void Heavy_WSTD_3Q::cCast_G4nvpY7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_BD3pOE9G_sendMessage);
}

void Heavy_WSTD_3Q::cSend_n9jQ3fKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xn2EZ5Gk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_KI5IRohg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EhO58oqs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_gzCGNskV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3CqTwQRX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_8lA6zB1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_L9exuBBI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L9exuBBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZFmyreN2, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZFmyreN2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZFmyreN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Z8bMR3us_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Z8bMR3us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gzCGNskV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_bQ59vmWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_s0QfGTmM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_s0QfGTmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MACfIwmr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yTDrVZzz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AAQfjHzO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_01vVCokl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TEpoJvTh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A4LIKLs4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MXHpAI6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1S323W4y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_uHQQxnYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_64A90bl2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_oS0A87hE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yLKZGatM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_fP6JUiPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SIjaGkfp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_nHBNCD5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NuAZSmzW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_P9LFvYAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8oqguZlG, 0, m, &cVar_8oqguZlG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9KwZJJcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WhQSiOIf, 1, m, &cVar_WhQSiOIf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AAQfjHzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fP6JUiPq, HV_BINOP_MULTIPLY, 0, m, &cBinop_fP6JUiPq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_01vVCokl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oS0A87hE, HV_BINOP_MULTIPLY, 0, m, &cBinop_oS0A87hE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TEpoJvTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHQQxnYv, HV_BINOP_MULTIPLY, 0, m, &cBinop_uHQQxnYv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MACfIwmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_A4LIKLs4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MXHpAI6g, HV_BINOP_MULTIPLY, 0, m, &cBinop_MXHpAI6g_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yTDrVZzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nHBNCD5H, HV_BINOP_MULTIPLY, 0, m, &cBinop_nHBNCD5H_sendMessage);
}

void Heavy_WSTD_3Q::cCast_92PYQKyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5ffUoVmn, 0, m, &cVar_5ffUoVmn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CWOdWZ9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WhQSiOIf, 0, m, &cVar_WhQSiOIf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_BfuDWlDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fZHoWUL1, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_YyhtOEmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vp57NZsc, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_pdjs40ER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LrkF5UON, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_aWVMWMm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nKGuUzGg, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_XbV2Micu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FvWxGg4C_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_FvWxGg4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AYArvYD5, HV_BINOP_DIVIDE, 1, m, &cBinop_AYArvYD5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Iif20k1J_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_C4USOTFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Hm0E9vSe_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_oc7hroQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_C4USOTFE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Hm0E9vSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AYArvYD5, HV_BINOP_DIVIDE, 0, m, &cBinop_AYArvYD5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Iif20k1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oc7hroQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_AYArvYD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qzuUf9G3, HV_BINOP_MULTIPLY, 1, m, &cBinop_qzuUf9G3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qzuUf9G3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W2iuzbs9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TLQu0Ask_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_CU9qbPID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HZsxsYOV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_owVi648a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CvRyCmHR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4hlLOovk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_MR0Ci0nS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MR0Ci0nS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qzuUf9G3, HV_BINOP_MULTIPLY, 0, m, &cBinop_qzuUf9G3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RvoKAuUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_IuUz1uPD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IuUz1uPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lrPb8Hx5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_32USHc9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_my2c2gkv, HV_BINOP_MULTIPLY, 1, m, &cBinop_my2c2gkv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XNLddVoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q4ByJEJI, 1, m, &cVar_q4ByJEJI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_swjIorel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IdBZcTXr, HV_BINOP_MULTIPLY, 1, m, &cBinop_IdBZcTXr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Prlir3SF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_211n0fkw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_211n0fkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlbPlh9i, HV_BINOP_MULTIPLY, 1, m, &cBinop_dlbPlh9i_sendMessage);
}

void Heavy_WSTD_3Q::cVar_q4ByJEJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aP4jdF2x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_kuvmLEwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WMzFJsqn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_4hlLOovk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2L6crxKY_sendMessage);
}

void Heavy_WSTD_3Q::cVar_BLANS34j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_RvoKAuUQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_W2iuzbs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_CU9qbPID_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TLQu0Ask_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_owVi648a_sendMessage);
}

void Heavy_WSTD_3Q::cSend_HZsxsYOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G15bxr9N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_CvRyCmHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZQB2pfX9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_hucaUfRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5Du7pEyv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_lrPb8Hx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wCPES3vG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wCPES3vG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6d8NxSer, HV_BINOP_MULTIPLY, 1, m, &cBinop_6d8NxSer_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6d8NxSer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DBWXnDG2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DBWXnDG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hucaUfRP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_aP4jdF2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Otk2kYWV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Otk2kYWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_20PYJAIL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QlKPYnin_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CCzPPjX6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FtGgV9Su_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HQvZEO1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BfuDWlDH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_my2c2gkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YyhtOEmZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_IdBZcTXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pdjs40ER_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_dlbPlh9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aWVMWMm7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_pCDBy11U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kuvmLEwl, 0, m, &cVar_kuvmLEwl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SjL1bDaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BLANS34j, 1, m, &cVar_BLANS34j_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2L6crxKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_q4ByJEJI, 0, m, &cVar_q4ByJEJI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WMzFJsqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BLANS34j, 0, m, &cVar_BLANS34j_sendMessage);
}

void Heavy_WSTD_3Q::cCast_20PYJAIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlbPlh9i, HV_BINOP_MULTIPLY, 0, m, &cBinop_dlbPlh9i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FtGgV9Su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HQvZEO1E, HV_BINOP_MULTIPLY, 0, m, &cBinop_HQvZEO1E_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QlKPYnin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IdBZcTXr, HV_BINOP_MULTIPLY, 0, m, &cBinop_IdBZcTXr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CCzPPjX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_my2c2gkv, HV_BINOP_MULTIPLY, 0, m, &cBinop_my2c2gkv_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_R6z77Tdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hZndcuK2, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yoVM9C4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jmjknroU, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_9MHMlXru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T7FpAd0z, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_wFlKiZIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZByKFldF, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yoMqHYlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0MZbKAk5, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_E4J3xZGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aglGqlvc_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_aglGqlvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sRB0XdGK, HV_BINOP_DIVIDE, 1, m, &cBinop_sRB0XdGK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cCJQMStx_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_bdPb6GBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_yBfSi1FO_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_MYco9EAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_bdPb6GBE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yBfSi1FO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sRB0XdGK, HV_BINOP_DIVIDE, 0, m, &cBinop_sRB0XdGK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cCJQMStx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MYco9EAT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sRB0XdGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vLhdccj6, HV_BINOP_MULTIPLY, 1, m, &cBinop_vLhdccj6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vLhdccj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8kxI1Rw4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jszTXtuJ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Qt1ESA9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_N6B5UkPo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_pgMJzfSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OKvPn8Wb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_GR1AMHl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_nFWWXgXp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nFWWXgXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vLhdccj6, HV_BINOP_MULTIPLY, 0, m, &cBinop_vLhdccj6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5WprGXJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_uKLxTk9b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uKLxTk9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KsdgCMa1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_zZwxuAM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UFM3rniq, HV_BINOP_MULTIPLY, 1, m, &cBinop_UFM3rniq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_USrBlXX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BSVUEZEC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BSVUEZEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zZwxuAM0_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8Og9XRkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1qkDaioz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1qkDaioz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3lD9gzkC, HV_BINOP_MULTIPLY, 1, m, &cBinop_3lD9gzkC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_I39WajQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ZR5xXQj, HV_BINOP_MULTIPLY, 1, m, &cBinop_3ZR5xXQj_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_eXXUipi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OD2dOMSa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OD2dOMSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_I39WajQc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QTnhJZAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9YxUAOFz, 1, m, &cVar_9YxUAOFz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hPDZGLxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t0E10vPf, HV_BINOP_MULTIPLY, 1, m, &cBinop_t0E10vPf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_LCcGzekS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_M6ATreSB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_M6ATreSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ekeLAJZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_4ekeLAJZ_sendMessage);
}

void Heavy_WSTD_3Q::cVar_9YxUAOFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DMAoTHsp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_fELeRnJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jUCjBuox_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_GR1AMHl0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fiBVurhu_sendMessage);
}

void Heavy_WSTD_3Q::cVar_OpgNg3cD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5WprGXJ7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8kxI1Rw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Qt1ESA9b_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jszTXtuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_pgMJzfSt_sendMessage);
}

void Heavy_WSTD_3Q::cSend_N6B5UkPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GzCO6Ln6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_OKvPn8Wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_L052lmIw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_WczFlzIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EOR9wv7x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_KsdgCMa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0zAV4y15_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0zAV4y15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YrWP05XV, HV_BINOP_MULTIPLY, 1, m, &cBinop_YrWP05XV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YrWP05XV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_THZJhyVc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_THZJhyVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WczFlzIR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_DMAoTHsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7xnL1wI0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7xnL1wI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DIoIHlxJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ElxsqPkR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nx7QWfmJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y7hFSkce_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FI3oFEdu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z7YHYgB9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UFM3rniq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R6z77Tdj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3lD9gzkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yoVM9C4y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3ZR5xXQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9MHMlXru_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_t0E10vPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wFlKiZIz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4ekeLAJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yoMqHYlj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_5IQQAoeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fELeRnJc, 0, m, &cVar_fELeRnJc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ah7uDOO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OpgNg3cD, 1, m, &cVar_OpgNg3cD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DIoIHlxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_ElxsqPkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ekeLAJZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_4ekeLAJZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FI3oFEdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3lD9gzkC, HV_BINOP_MULTIPLY, 0, m, &cBinop_3lD9gzkC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_y7hFSkce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ZR5xXQj, HV_BINOP_MULTIPLY, 0, m, &cBinop_3ZR5xXQj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nx7QWfmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t0E10vPf, HV_BINOP_MULTIPLY, 0, m, &cBinop_t0E10vPf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_z7YHYgB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UFM3rniq, HV_BINOP_MULTIPLY, 0, m, &cBinop_UFM3rniq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jUCjBuox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OpgNg3cD, 0, m, &cVar_OpgNg3cD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fiBVurhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9YxUAOFz, 0, m, &cVar_9YxUAOFz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Bb4wdtfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AoO5nz9A, 1, m, &cIf_AoO5nz9A_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_yYdbVtbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_W2uVrAZj, m);
}

void Heavy_WSTD_3Q::cBinop_QzK1BL8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yYdbVtbM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Qq6PpzQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AoO5nz9A, 0, m, &cIf_AoO5nz9A_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_IeOteQtC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C1YR9VZT, 0, m, &cSlice_C1YR9VZT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_l46epTcq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_C1YR9VZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Xz4sY8b8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Xz4sY8b8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_6PtSeMCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Xz4sY8b8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Xz4sY8b8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Iu2NdJ8b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_XMpNV7h4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mZuJv9Ws_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_TeAEe0F6, 0, m, &cIf_TeAEe0F6_sendMessage);
}

void Heavy_WSTD_3Q::cIf_TeAEe0F6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_md8ci7vd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_wB6FtzWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_CcKOI09A_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_E8HWyZIR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_35tFH93F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LMBhFWPT, HV_BINOP_POW, 0, m, &cBinop_LMBhFWPT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LMBhFWPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VdEnhOpT, 0, m, &cIf_VdEnhOpT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nKrcpwJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_sM0jt2on_sendMessage);
}

void Heavy_WSTD_3Q::cCast_eL5UpPA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KnUhVuva_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CyIPNZnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wB6FtzWN, 0, m, &cIf_wB6FtzWN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KnUhVuva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wB6FtzWN, 1, m, &cIf_wB6FtzWN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_E8HWyZIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_nKrcpwJv_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_CcKOI09A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VdEnhOpT, 0, m, &cIf_VdEnhOpT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sM0jt2on_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LMBhFWPT, HV_BINOP_POW, 1, m, &cBinop_LMBhFWPT_sendMessage);
  cMsg_35tFH93F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_VdEnhOpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_5mOXxqVA, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_mZuJv9Ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TeAEe0F6, 1, m, &cIf_TeAEe0F6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_md8ci7vd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8FNXnwR2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_8FNXnwR2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aLeJRct2, HV_BINOP_EQ, 1, m, &cBinop_aLeJRct2_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_qfuVgORp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A7ZK7D4K, HV_BINOP_ADD, 0, m, &cBinop_A7ZK7D4K_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_A7ZK7D4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eL5UpPA0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CyIPNZnn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8FNXnwR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VdEnhOpT, 1, m, &cIf_VdEnhOpT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aLeJRct2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LA3kgGkP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_LA3kgGkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5mOXxqVA, m);
}

void Heavy_WSTD_3Q::cCast_2zXnngpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A7ZK7D4K, HV_BINOP_ADD, 1, m, &cBinop_A7ZK7D4K_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8FNXnwR2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_8FNXnwR2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aLeJRct2, HV_BINOP_EQ, 0, m, &cBinop_aLeJRct2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0tsRchWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XMpNV7h4, 0, m, &cVar_XMpNV7h4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0d2OE5gF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qfuVgORp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_JNRuM1eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FzE2DD29_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_TkBu4xYN, 0, m, &cIf_TkBu4xYN_sendMessage);
}

void Heavy_WSTD_3Q::cIf_TkBu4xYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KMSmJF6J_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_gmYhvx31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9yole5f0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_14oaH5PN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_V3asV2gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_auBA7b2w, HV_BINOP_POW, 0, m, &cBinop_auBA7b2w_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_auBA7b2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q8Fi83x9, 0, m, &cIf_Q8Fi83x9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zeTm68vJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cSB4ykc9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_m65L0HbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gmYhvx31, 0, m, &cIf_gmYhvx31_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fOWvZXq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_t2fnhTHf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t2fnhTHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gmYhvx31, 1, m, &cIf_gmYhvx31_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_14oaH5PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zeTm68vJ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9yole5f0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Q8Fi83x9, 0, m, &cIf_Q8Fi83x9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cSB4ykc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_auBA7b2w, HV_BINOP_POW, 1, m, &cBinop_auBA7b2w_sendMessage);
  cMsg_V3asV2gx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_Q8Fi83x9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AI94Sn9i_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_q6LOiMhL_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_ulkif51k_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_FzE2DD29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TkBu4xYN, 1, m, &cIf_TkBu4xYN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KMSmJF6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vFDCuxtg, HV_BINOP_GREATER_THAN, 1, m, &cBinop_vFDCuxtg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dxoj6mNI, HV_BINOP_EQ, 1, m, &cBinop_dxoj6mNI_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_dOLSP4GH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yBkHs461, HV_BINOP_ADD, 0, m, &cBinop_yBkHs461_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yBkHs461_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fOWvZXq5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m65L0HbI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vFDCuxtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q8Fi83x9, 1, m, &cIf_Q8Fi83x9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dxoj6mNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RqVpmlOa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_RqVpmlOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AI94Sn9i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_q6LOiMhL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_ulkif51k_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TkI0IbUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JNRuM1eh, 0, m, &cVar_JNRuM1eh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_q7aP9Y0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dOLSP4GH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_srm629WX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yBkHs461, HV_BINOP_ADD, 1, m, &cBinop_yBkHs461_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vFDCuxtg, HV_BINOP_GREATER_THAN, 0, m, &cBinop_vFDCuxtg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dxoj6mNI, HV_BINOP_EQ, 0, m, &cBinop_dxoj6mNI_sendMessage);
}

void Heavy_WSTD_3Q::cVar_1gBKGqpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9KhVhzOm_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_4yHU3RIp, 0, m, &cIf_4yHU3RIp_sendMessage);
}

void Heavy_WSTD_3Q::cIf_4yHU3RIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iXt64Hxn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_urwjLQcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ZpgMK1yA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_MJNTmBvk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_bJYf8v58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqgBsu19, HV_BINOP_POW, 0, m, &cBinop_aqgBsu19_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aqgBsu19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KIvkkBgS, 0, m, &cIf_KIvkkBgS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Afyw3eLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_rNmPu0gJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8pDG7Igo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gQgxfpcI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SSC9qSHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_urwjLQcM, 0, m, &cIf_urwjLQcM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gQgxfpcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_urwjLQcM, 1, m, &cIf_urwjLQcM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MJNTmBvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Afyw3eLb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZpgMK1yA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_KIvkkBgS, 0, m, &cIf_KIvkkBgS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rNmPu0gJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqgBsu19, HV_BINOP_POW, 1, m, &cBinop_aqgBsu19_sendMessage);
  cMsg_bJYf8v58_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_KIvkkBgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_j7lQpyvy, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_9KhVhzOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4yHU3RIp, 1, m, &cIf_4yHU3RIp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iXt64Hxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_suxfN32j, HV_BINOP_GREATER_THAN, 1, m, &cBinop_suxfN32j_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bAngISnm, HV_BINOP_EQ, 1, m, &cBinop_bAngISnm_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_kWDO7OOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WN1OVwBi, HV_BINOP_ADD, 0, m, &cBinop_WN1OVwBi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WN1OVwBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8pDG7Igo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SSC9qSHn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_suxfN32j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KIvkkBgS, 1, m, &cIf_KIvkkBgS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bAngISnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JqK2VN0S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_JqK2VN0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_j7lQpyvy, m);
}

void Heavy_WSTD_3Q::cCast_JUDxKwVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kWDO7OOP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_6blHE8co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1gBKGqpF, 0, m, &cVar_1gBKGqpF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xwUsuzqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WN1OVwBi, HV_BINOP_ADD, 1, m, &cBinop_WN1OVwBi_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_suxfN32j, HV_BINOP_GREATER_THAN, 0, m, &cBinop_suxfN32j_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bAngISnm, HV_BINOP_EQ, 0, m, &cBinop_bAngISnm_sendMessage);
}

void Heavy_WSTD_3Q::cIf_VNLWPOvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_u2Gj6A5e, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_tGQupsC7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qqiFlhV4, 0, m, &cSlice_qqiFlhV4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MpLjkerC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_qqiFlhV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JdCNHBjR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JdCNHBjR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_md3gaH5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JdCNHBjR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_JdCNHBjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IK8U8HpD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_MpLjkerC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_E8oA6SC0, 0, m, &cSlice_E8oA6SC0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IeOteQtC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_E8oA6SC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Kw6QIC9x_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Kw6QIC9x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_aG8zIs03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Kw6QIC9x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Kw6QIC9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n13rJuj1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_l46epTcq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AgwGG9VX, 0, m, &cSlice_AgwGG9VX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Cl0frhAj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_AgwGG9VX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hA3ddixc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hA3ddixc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_uCtaIUGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hA3ddixc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_hA3ddixc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8XWwscef_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_Cl0frhAj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_coOBIajW, 0, m, &cSlice_coOBIajW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_coOBIajW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zyB1gCY9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zyB1gCY9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_iZsjjIQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zyB1gCY9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zyB1gCY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xQdLNS2O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_EzGxlyAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EVVK5FiP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_aJPNfcKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bJsh7miV, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_RVsfTwUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z4PoDuAR, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_5k9K94Gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sOLsYpch, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_0EjToQtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s3HqKmzu, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_lQOjeLrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GZ4uyLEK_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_GZ4uyLEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TodGaHMC, HV_BINOP_DIVIDE, 1, m, &cBinop_TodGaHMC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VWMP3SLo_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Zzfx2NOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_bj6WRlHQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lXv1uEpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Zzfx2NOv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bj6WRlHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TodGaHMC, HV_BINOP_DIVIDE, 0, m, &cBinop_TodGaHMC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VWMP3SLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lXv1uEpg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_TodGaHMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FkrVSsN8, HV_BINOP_MULTIPLY, 1, m, &cBinop_FkrVSsN8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FkrVSsN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fjP5JPFU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cxi4pVzo_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_C6jHmold_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NLCEUfgs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_xk54Bedr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UvXTx0p9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vbfu18v7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_7k72xhsk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7k72xhsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FkrVSsN8, HV_BINOP_MULTIPLY, 0, m, &cBinop_FkrVSsN8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6ffatlCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dpQ9zChU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dpQ9zChU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KheTrfAa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9Ju2gur8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f8mRk0fj, 1, m, &cVar_f8mRk0fj_sendMessage);
}

void Heavy_WSTD_3Q::cVar_f8mRk0fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Om9ZP0QC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kd1OJNYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0NVpk27E, HV_BINOP_MULTIPLY, 1, m, &cBinop_0NVpk27E_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VzTpi4Jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kd1OJNYR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lkX0Vj6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_32TOtWJV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_32TOtWJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V9OjJmIn, HV_BINOP_MULTIPLY, 1, m, &cBinop_V9OjJmIn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_m96VvKc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jFtZQDtp, HV_BINOP_MULTIPLY, 1, m, &cBinop_jFtZQDtp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Mgheyfl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_m96VvKc1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SwgM1h9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CQsWp4Xj, HV_BINOP_MULTIPLY, 1, m, &cBinop_CQsWp4Xj_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Q38nR67w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QnKLsWAN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QnKLsWAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PUkj6WYG, HV_BINOP_MULTIPLY, 1, m, &cBinop_PUkj6WYG_sendMessage);
}

void Heavy_WSTD_3Q::cVar_cK2mrvSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wf7jiLPn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_vbfu18v7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vP28QwYr_sendMessage);
}

void Heavy_WSTD_3Q::cVar_NrAVmnNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6ffatlCj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fjP5JPFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_C6jHmold_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Cxi4pVzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_xk54Bedr_sendMessage);
}

void Heavy_WSTD_3Q::cSend_NLCEUfgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UPgMZivY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_UvXTx0p9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U23Ojk1v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_loXEDleK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JawAijLi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_KheTrfAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_n5mjr5hT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_n5mjr5hT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GGAP2qxN, HV_BINOP_MULTIPLY, 1, m, &cBinop_GGAP2qxN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GGAP2qxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Gv3HdWnu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Gv3HdWnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_loXEDleK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Om9ZP0QC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wMoAalii_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wMoAalii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2dPZwh6m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L2IEn69a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_imxcPRlB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4GL1MDyn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wDDzT83K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sSSwk7jw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0NVpk27E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EzGxlyAM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_V9OjJmIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aJPNfcKv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jFtZQDtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RVsfTwUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_CQsWp4Xj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5k9K94Gg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PUkj6WYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0EjToQtb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_bv5rZl26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NrAVmnNQ, 1, m, &cVar_NrAVmnNQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mATchStj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cK2mrvSJ, 0, m, &cVar_cK2mrvSJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_imxcPRlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CQsWp4Xj, HV_BINOP_MULTIPLY, 0, m, &cBinop_CQsWp4Xj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wDDzT83K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V9OjJmIn, HV_BINOP_MULTIPLY, 0, m, &cBinop_V9OjJmIn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2dPZwh6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_L2IEn69a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PUkj6WYG, HV_BINOP_MULTIPLY, 0, m, &cBinop_PUkj6WYG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sSSwk7jw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0NVpk27E, HV_BINOP_MULTIPLY, 0, m, &cBinop_0NVpk27E_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4GL1MDyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jFtZQDtp, HV_BINOP_MULTIPLY, 0, m, &cBinop_jFtZQDtp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vP28QwYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f8mRk0fj, 0, m, &cVar_f8mRk0fj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wf7jiLPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NrAVmnNQ, 0, m, &cVar_NrAVmnNQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bPdigsa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H03pO37L, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Th0eommj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KJ5viBBS, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_he6NEH06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GVQKD24T, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_kWqoe8DU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VaJiV5gc, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_FPwBiwtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Pr5cS7Pa_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_Pr5cS7Pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tnv8MPjH, HV_BINOP_DIVIDE, 1, m, &cBinop_tnv8MPjH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9VjZRznF_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Q7TU1WBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_XtBFOCFx_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xiPnIJJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Q7TU1WBC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XtBFOCFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tnv8MPjH, HV_BINOP_DIVIDE, 0, m, &cBinop_tnv8MPjH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9VjZRznF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xiPnIJJa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_tnv8MPjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z5kSGmZ1, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z5kSGmZ1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Z5kSGmZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m4B4LPAy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bwXPYkin_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_wVduZWjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rbY0J7Ai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_sDVvzBoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dltWdryT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3bEiY3Y4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_50ry3Z1k_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_50ry3Z1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z5kSGmZ1, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z5kSGmZ1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0UKf31bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_LwlhxKRX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LwlhxKRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AgeEnjYc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_zk2PDfJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qZDJLtLf, HV_BINOP_MULTIPLY, 1, m, &cBinop_qZDJLtLf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jDQMYAPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xSMRQzss, 1, m, &cVar_xSMRQzss_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iq9CIgCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lvveqj3H, HV_BINOP_MULTIPLY, 1, m, &cBinop_lvveqj3H_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xSKtjQI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AQNeiPsh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AQNeiPsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RWGO6O7S, HV_BINOP_MULTIPLY, 1, m, &cBinop_RWGO6O7S_sendMessage);
}

void Heavy_WSTD_3Q::cVar_xSMRQzss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lcPim6JN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_fxZmkDeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q83lbYEg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3bEiY3Y4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YI5YVNVH_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ilUuHvL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_0UKf31bm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bwXPYkin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_sDVvzBoP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_m4B4LPAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_wVduZWjV_sendMessage);
}

void Heavy_WSTD_3Q::cSend_rbY0J7Ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AM5N3Zy1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_dltWdryT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LCc2L5V1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_HdVlMar2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MUkVcVCU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_AgeEnjYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KQSIogaI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KQSIogaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I0duw0Gt, HV_BINOP_MULTIPLY, 1, m, &cBinop_I0duw0Gt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_I0duw0Gt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gekVcHVN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gekVcHVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HdVlMar2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_lcPim6JN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TLa3ip2M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TLa3ip2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cFxeoEca_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SrHA7iok_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ujHpQuNV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hNeq7TDY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uSAUsmGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bPdigsa3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qZDJLtLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Th0eommj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lvveqj3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_he6NEH06_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_RWGO6O7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kWqoe8DU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_clI4AXyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fxZmkDeh, 0, m, &cVar_fxZmkDeh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_m4zOQfT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ilUuHvL3, 1, m, &cVar_ilUuHvL3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YI5YVNVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xSMRQzss, 0, m, &cVar_xSMRQzss_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Q83lbYEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ilUuHvL3, 0, m, &cVar_ilUuHvL3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SrHA7iok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lvveqj3H, HV_BINOP_MULTIPLY, 0, m, &cBinop_lvveqj3H_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hNeq7TDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uSAUsmGC, HV_BINOP_MULTIPLY, 0, m, &cBinop_uSAUsmGC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cFxeoEca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RWGO6O7S, HV_BINOP_MULTIPLY, 0, m, &cBinop_RWGO6O7S_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ujHpQuNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qZDJLtLf, HV_BINOP_MULTIPLY, 0, m, &cBinop_qZDJLtLf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_puKyHQjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2Wm7w12W, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_3z3WnQz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JkSEu3uQ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_FAO74HyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hmM1f5rH, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_L108jrwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hpdru6Xd, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6AvtYoCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_USJljXyD, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_KgdPkxst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_00i3hwXf_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_00i3hwXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TdGBViL7, HV_BINOP_DIVIDE, 1, m, &cBinop_TdGBViL7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p4B0AAy2_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_izb6jp3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_IwXtE6ls_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Udgr4W0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_izb6jp3e_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IwXtE6ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TdGBViL7, HV_BINOP_DIVIDE, 0, m, &cBinop_TdGBViL7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_p4B0AAy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Udgr4W0g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_TdGBViL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_356xZB72, HV_BINOP_MULTIPLY, 1, m, &cBinop_356xZB72_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_356xZB72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XhBrYNVS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2mJkzTIh_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_awNdtf0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GIRnLQXP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_nqvEPnsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OZ7ifdux_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_INhcdyFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_XGQvPVJV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XGQvPVJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_356xZB72, HV_BINOP_MULTIPLY, 0, m, &cBinop_356xZB72_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kRWnhK43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_tBwCerr5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tBwCerr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S9eSWjgL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mm5I8rGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z2IAQkWH, HV_BINOP_MULTIPLY, 1, m, &cBinop_Z2IAQkWH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_HFZKw2Eo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FDCOTFVf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FDCOTFVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mm5I8rGN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZkWD2oUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nEXEerGz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nEXEerGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xkMVx5bF, HV_BINOP_MULTIPLY, 1, m, &cBinop_xkMVx5bF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_obLQW7kt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_llN1v8U4, HV_BINOP_MULTIPLY, 1, m, &cBinop_llN1v8U4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_eOsjI4dH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uDfteoLC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uDfteoLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_obLQW7kt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hnjpzGHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SLcYWcra, 1, m, &cVar_SLcYWcra_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_S7FMug0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SsdXK3Df, HV_BINOP_MULTIPLY, 1, m, &cBinop_SsdXK3Df_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nBuTVphm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_G1AxWbkz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_G1AxWbkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eJYh2GGd, HV_BINOP_MULTIPLY, 1, m, &cBinop_eJYh2GGd_sendMessage);
}

void Heavy_WSTD_3Q::cVar_SLcYWcra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uIkTEGEw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_fa4U28tJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xJ6HsYdk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_INhcdyFL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KjilWNvV_sendMessage);
}

void Heavy_WSTD_3Q::cVar_dO9OfqD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kRWnhK43_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XhBrYNVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_awNdtf0f_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2mJkzTIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_nqvEPnsY_sendMessage);
}

void Heavy_WSTD_3Q::cSend_GIRnLQXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aPb7YcJG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_OZ7ifdux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cMJevt1q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_wRqlpOVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Raoxc9HE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_S9eSWjgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3l44F52I_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3l44F52I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhDIWFAd, HV_BINOP_MULTIPLY, 1, m, &cBinop_dhDIWFAd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dhDIWFAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5oD76EdM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5oD76EdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wRqlpOVB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_uIkTEGEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MqX08dnF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MqX08dnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HJx89Vey_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GNFcqJzI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oYB7YQC9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_isDF02cT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rq7JqrGy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q56hsLrD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Z2IAQkWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_puKyHQjv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xkMVx5bF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3z3WnQz6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_llN1v8U4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FAO74HyP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SsdXK3Df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L108jrwD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_eJYh2GGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6AvtYoCe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_cTXxyfTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dO9OfqD6, 1, m, &cVar_dO9OfqD6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1U45GwyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fa4U28tJ, 0, m, &cVar_fa4U28tJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_isDF02cT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_llN1v8U4, HV_BINOP_MULTIPLY, 0, m, &cBinop_llN1v8U4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oYB7YQC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SsdXK3Df, HV_BINOP_MULTIPLY, 0, m, &cBinop_SsdXK3Df_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HJx89Vey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_Q56hsLrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z2IAQkWH, HV_BINOP_MULTIPLY, 0, m, &cBinop_Z2IAQkWH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rq7JqrGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xkMVx5bF, HV_BINOP_MULTIPLY, 0, m, &cBinop_xkMVx5bF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GNFcqJzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eJYh2GGd, HV_BINOP_MULTIPLY, 0, m, &cBinop_eJYh2GGd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xJ6HsYdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dO9OfqD6, 0, m, &cVar_dO9OfqD6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KjilWNvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SLcYWcra, 0, m, &cVar_SLcYWcra_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AI94Sn9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VNLWPOvp, 1, m, &cIf_VNLWPOvp_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_sWv9DCMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_u2Gj6A5e, m);
}

void Heavy_WSTD_3Q::cBinop_q6LOiMhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sWv9DCMK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ulkif51k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VNLWPOvp, 0, m, &cIf_VNLWPOvp_sendMessage);
}

void Heavy_WSTD_3Q::cVar_i95C4GMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jHVUOC8o, HV_BINOP_DIVIDE, 0, m, &cBinop_jHVUOC8o_sendMessage);
}

void Heavy_WSTD_3Q::cVar_khBdbFRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MMg1mQEl, HV_BINOP_DIVIDE, 1, m, &cBinop_MMg1mQEl_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jHVUOC8o, HV_BINOP_DIVIDE, 1, m, &cBinop_jHVUOC8o_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_7pkxf6Ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ziXO4ABH, HV_BINOP_DIVIDE, 0, m, &cBinop_ziXO4ABH_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_0sqQE4zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ziXO4ABH, HV_BINOP_DIVIDE, 1, m, &cBinop_ziXO4ABH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0ForQlcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i95C4GMz, 0, m, &cVar_i95C4GMz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_B3mzbGBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MMg1mQEl, HV_BINOP_DIVIDE, 0, m, &cBinop_MMg1mQEl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bzGI38wL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_khBdbFRa, 0, m, &cVar_khBdbFRa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MMg1mQEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_7pkxf6Ur_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jHVUOC8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_0sqQE4zp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ziXO4ABH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_AEQ5jHiF_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_yyAwZJWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_WPs7qsHu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_52NZlhlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_Vkb4wKOW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AEQ5jHiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_52NZlhlW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Vkb4wKOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_yyAwZJWw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WPs7qsHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XkdmSNQK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_mXErZxjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2b1Lea4Q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tGQupsC7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_9DRKtcV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2b1Lea4Q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tGQupsC7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ZNCwMNfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2b1Lea4Q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tGQupsC7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Ahjjyo7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2b1Lea4Q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tGQupsC7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_XkdmSNQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2b1Lea4Q_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tGQupsC7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Etm8XjvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_5mkpxFet, 0, m, &cVar_5mkpxFet_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GqhOAbqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Nj7A0jXI, 0, m, &cVar_Nj7A0jXI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1ApRwfO8, 0, m, &cVar_1ApRwfO8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Eb40xFpb, 0, m, &cVar_Eb40xFpb_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_rv4RHG2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Nj7A0jXI, 0, m, &cVar_Nj7A0jXI_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_9Y7INKoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1ApRwfO8, 0, m, &cVar_1ApRwfO8_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_2lyLjGuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Eb40xFpb, 0, m, &cVar_Eb40xFpb_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_oENBPccu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kuvmLEwl, 0, m, &cVar_kuvmLEwl_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_kuQYi7aY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SjL1bDaL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pCDBy11U_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_GiEZ3DhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uY5aM5MG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3QLHMHDx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bfwc6Ki0_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_lnYOYWrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FzdO5FLo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_grIspvNi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BRw8hG3g_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_b4V1krvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Olsnmm9g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uivRxPBv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6Vo8Ey9A_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_KsFxmWEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a67sCqRM_sendMessage(_c, 0, m);
  cMsg_XbV2Micu_sendMessage(_c, 0, m);
  cMsg_E4J3xZGO_sendMessage(_c, 0, m);
  cMsg_lQOjeLrt_sendMessage(_c, 0, m);
  cMsg_FPwBiwtb_sendMessage(_c, 0, m);
  cMsg_KgdPkxst_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8oqguZlG, 0, m, &cVar_8oqguZlG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kuvmLEwl, 0, m, &cVar_kuvmLEwl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fELeRnJc, 0, m, &cVar_fELeRnJc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cK2mrvSJ, 0, m, &cVar_cK2mrvSJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fxZmkDeh, 0, m, &cVar_fxZmkDeh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fa4U28tJ, 0, m, &cVar_fa4U28tJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n06GRgYT, 0, m, &cVar_n06GRgYT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JssBPvCQ, 0, m, &cVar_JssBPvCQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wt2UsAvq, 0, m, &cVar_wt2UsAvq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4Y2wbZNW, 0, m, &cVar_4Y2wbZNW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XTVk1tW8, 0, m, &cVar_XTVk1tW8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_loRgjkXF, 0, m, &cVar_loRgjkXF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wWIchYJP, 0, m, &cVar_wWIchYJP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pEKflCfs, 0, m, &cVar_pEKflCfs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6PtSeMCw, 0, m, &cVar_6PtSeMCw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XMpNV7h4, 0, m, &cVar_XMpNV7h4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JNRuM1eh, 0, m, &cVar_JNRuM1eh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1gBKGqpF, 0, m, &cVar_1gBKGqpF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_md3gaH5s, 0, m, &cVar_md3gaH5s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aG8zIs03, 0, m, &cVar_aG8zIs03_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uCtaIUGc, 0, m, &cVar_uCtaIUGc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iZsjjIQh, 0, m, &cVar_iZsjjIQh_sendMessage);
  cMsg_GqhOAbqV_sendMessage(_c, 0, m);
  cMsg_Etm8XjvK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_xn2EZ5Gk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZFmyreN2, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZFmyreN2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_EhO58oqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NBFyLZdH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BI3uX2N2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NIhv97ZB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_4Ovu0JXh_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3CqTwQRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_P2GxwYI1_sendMessage);
  cMsg_L5YRkXuz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_G15bxr9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6d8NxSer, HV_BINOP_MULTIPLY, 0, m, &cBinop_6d8NxSer_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZQB2pfX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_swjIorel_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_5Du7pEyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HQvZEO1E, HV_BINOP_MULTIPLY, 1, m, &cBinop_HQvZEO1E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_32USHc9c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XNLddVoR_sendMessage);
  cMsg_Prlir3SF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_GzCO6Ln6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YrWP05XV, HV_BINOP_MULTIPLY, 0, m, &cBinop_YrWP05XV_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_L052lmIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_USrBlXX6_sendMessage(_c, 0, m);
  cMsg_8Og9XRkv_sendMessage(_c, 0, m);
  cMsg_eXXUipi4_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_hPDZGLxI_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_EOR9wv7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QTnhJZAy_sendMessage);
  cMsg_LCcGzekS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_Iu2NdJ8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fxZmkDeh, 0, m, &cVar_fxZmkDeh_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_xQdLNS2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m4zOQfT2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_clI4AXyH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_IK8U8HpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0tsRchWN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2zXnngpU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0d2OE5gF_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_8XWwscef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6blHE8co_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xwUsuzqK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JUDxKwVB_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_n13rJuj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TkI0IbUR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_srm629WX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q7aP9Y0U_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_UPgMZivY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GGAP2qxN, HV_BINOP_MULTIPLY, 0, m, &cBinop_GGAP2qxN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_U23Ojk1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VzTpi4Jq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lkX0Vj6z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Mgheyfl5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_SwgM1h9H_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_JawAijLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9Ju2gur8_sendMessage);
  cMsg_Q38nR67w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_AM5N3Zy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I0duw0Gt, HV_BINOP_MULTIPLY, 0, m, &cBinop_I0duw0Gt_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LCc2L5V1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_iq9CIgCo_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_MUkVcVCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uSAUsmGC, HV_BINOP_MULTIPLY, 1, m, &cBinop_uSAUsmGC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zk2PDfJq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jDQMYAPa_sendMessage);
  cMsg_xSKtjQI1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_aPb7YcJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dhDIWFAd, HV_BINOP_MULTIPLY, 0, m, &cBinop_dhDIWFAd_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_cMJevt1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HFZKw2Eo_sendMessage(_c, 0, m);
  cMsg_ZkWD2oUk_sendMessage(_c, 0, m);
  cMsg_eOsjI4dH_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_S7FMug0L_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Raoxc9HE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_hnjpzGHx_sendMessage);
  cMsg_nBuTVphm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_5KzBaSQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5mkpxFet, 0, m, &cVar_5mkpxFet_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_QfGXxSFS, VOf(Bf0));
    __hv_line_f(&sLine_smmF09l7, VOf(Bf1));
    __hv_line_f(&sLine_qIngFiam, VOf(Bf2));
    __hv_line_f(&sLine_0xME2TUq, VOf(Bf3));
    __hv_line_f(&sLine_NHAbj9xM, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_XUSch42Z, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_fdwgQdr4, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_fZHoWUL1, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_vp57NZsc, VOf(Bf1));
    __hv_line_f(&sLine_LrkF5UON, VOf(Bf0));
    __hv_line_f(&sLine_nKGuUzGg, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_SCKUsQW5, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_W2uVrAZj, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_hZndcuK2, VOf(Bf5));
    __hv_line_f(&sLine_jmjknroU, VOf(Bf1));
    __hv_line_f(&sLine_T7FpAd0z, VOf(Bf2));
    __hv_line_f(&sLine_ZByKFldF, VOf(Bf4));
    __hv_line_f(&sLine_0MZbKAk5, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_EtFzUE8T, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_dGbVYz7D, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_EVVK5FiP, VOf(Bf6));
    __hv_line_f(&sLine_bJsh7miV, VOf(Bf2));
    __hv_line_f(&sLine_Z4PoDuAR, VOf(Bf1));
    __hv_line_f(&sLine_sOLsYpch, VOf(Bf5));
    __hv_line_f(&sLine_s3HqKmzu, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_mM3O0BVI, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_5mOXxqVA, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_H03pO37L, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_KJ5viBBS, VOf(Bf2));
    __hv_line_f(&sLine_GVQKD24T, VOf(Bf6));
    __hv_line_f(&sLine_VaJiV5gc, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_8LyX5g46, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_u2Gj6A5e, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_2Wm7w12W, VOf(Bf8));
    __hv_line_f(&sLine_JkSEu3uQ, VOf(Bf2));
    __hv_line_f(&sLine_hmM1f5rH, VOf(Bf1));
    __hv_line_f(&sLine_hpdru6Xd, VOf(Bf7));
    __hv_line_f(&sLine_USJljXyD, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_3884Ebxj, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_j7lQpyvy, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
